@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,10 +32,10 @@ bool IncDecVolumeCommandLineOption::identify(const QString & str) const
         str == QString("--volume-dec")
     )
     {
-        return TRUE;
+        return true;
     }
 
-    return FALSE;
+    return false;
 }
 
 const QString IncDecVolumeCommandLineOption::helpString() const
@@ -46,10 +46,9 @@ const QString IncDecVolumeCommandLineOption::helpString() const
             );
 }
 
-
-void IncDecVolumeCommandLineOption::executeCommand(const QString& opt_str, CommandLineManager* clm)
+QString IncDecVolumeCommandLineOption::executeCommand(const QString& opt_str, const QStringList &args)
 {
-    Q_UNUSED(clm);
+    Q_UNUSED(args);
     SoundCore *core = SoundCore::instance();
     int volume = qMax(core->leftVolume(), core->rightVolume());
     int balance = 0;
@@ -68,6 +67,7 @@ void IncDecVolumeCommandLineOption::executeCommand(const QString& opt_str, Comma
     }
     core->setVolume(volume-qMax(balance,0)*volume/100,
                     volume+qMin(balance,0)*volume/100);
+    return QString();
 }
 
 const QString IncDecVolumeCommandLineOption::name() const
@@ -83,4 +83,4 @@ QTranslator *IncDecVolumeCommandLineOption::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(IncDecVolumeCommandLineOption)
+Q_EXPORT_PLUGIN2(incdecvolumeoption, IncDecVolumeCommandLineOption)
