@@ -72,7 +72,7 @@
     </message>
     <message>
         <location filename="../qmmpfiledialog.cpp" line="131"/>
-        <source>Writen by:
+        <source>Written by:
 Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autoren:
