@@ -20,6 +20,7 @@
 
 #include <QFile>
 #include <QDir>
+#include <QDirIterator>
 #include <QSettings>
 #include <QTextStream>
 #include <QTextCodec>
@@ -30,8 +31,18 @@
 #endif
 #include "cueparser.h"
 
-CUEParser::CUEParser(const QString &fileName)
+CUEParser::CUEParser(const QString &url)
 {
+    QString fileName = url;
+    if(url.contains("://"))
+    {
+        QString p = QUrl(url).path();
+        p.replace(QString(QUrl::toPercentEncoding("#")), "#");
+        p.replace(QString(QUrl::toPercentEncoding("?")), "?");
+        p.replace(QString(QUrl::toPercentEncoding("%")), "%");
+        p.replace(QString(QUrl::toPercentEncoding(":")), ":");
+        fileName = p;
+    }
     QFile file(fileName);
     if (!file.open(QIODevice::ReadOnly))
     {
@@ -44,6 +55,7 @@ CUEParser::CUEParser(const QString &fileName)
     QTextCodec *codec = QTextCodec::codecForName(settings.value("encoding","ISO-8859-1").toByteArray ());
     if(!codec)
         codec = QTextCodec::codecForName("UTF-8");
+    m_dirty = settings.value("dirty_cue", false).toBool();
 #ifdef WITH_ENCA
     EncaAnalyser analyser = 0;
     if(settings.value("use_enca", false).toBool())
@@ -88,7 +100,7 @@ CUEParser::CUEParser(const QString &fileName)
                 else
                     m_infoList.last().setLength(0);
             }
-            file_path = QFileInfo(fileName).dir().filePath(words[1]);
+            file_path = getDirtyPath(fileName, QFileInfo(fileName).dir().filePath(words[1]));
             new_file = true;
         }
 
@@ -112,6 +124,7 @@ CUEParser::CUEParser(const QString &fileName)
             path.replace("%", QString(QUrl::toPercentEncoding("%"))); //replace special symbols
             path.replace("#", QString(QUrl::toPercentEncoding("#")));
             path.replace("?", QString(QUrl::toPercentEncoding("?")));
+            path.replace(":", QString(QUrl::toPercentEncoding(":")));
             FileInfo info("cue://" + path + QString("#%1").arg(words[1].toInt()));
             info.setMetaData(Qmmp::TRACK, words[1].toInt());
             info.setMetaData(Qmmp::ALBUM, album);
@@ -247,3 +260,50 @@ qint64 CUEParser::getLength(const QString &str)
         return (qint64)list.at(0).toInt()*60000 + list.at(1).toInt()*1000 + list.at(2).toInt()*1000/75;
     return 0;
 }
+
+QString CUEParser::getDirtyPath(const QString &cue, const QString &path)
+{
+
+    if (Decoder::findByPath(path) || ! m_dirty)
+        return path;
+
+    QStringList candidates;
+    QDirIterator it(QFileInfo(path).dir().path(), QDir::Files);
+    while (it.hasNext())
+    {
+        it.next();
+        QString f = it.filePath();
+        if ((f != cue) && Decoder::findByPath(f))
+            candidates.push_back(f);
+    }
+
+    if (candidates.empty())
+        return path;
+    else if (candidates.count() == 1)
+        return candidates.first();
+
+    int dot = cue.lastIndexOf('.');
+    if (dot != -1)
+    {
+        QRegExp r(QRegExp::escape(cue.left(dot)) + "\\.[^\\.]+$");
+
+        int index = candidates.indexOf(r);
+        int rindex = candidates.lastIndexOf(r);
+
+        if ((index != -1) && (index == rindex))
+            return candidates[index];
+    }
+    dot = path.lastIndexOf('.');
+    if (dot != -1)
+    {
+        QRegExp r(QRegExp::escape(path.left(dot)) + "\\.[^\\.]+$");
+
+        int index = candidates.indexOf(r);
+        int rindex = candidates.lastIndexOf(r);
+
+        if ((index != -1) && (index == rindex))
+            return candidates[index];
+    }
+
+    return path;
+}
