@@ -14,18 +14,18 @@
         <translation>Brani CUE</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="85"/>
+        <location filename="../decodercuefactory.cpp" line="95"/>
         <source>About CUE Audio Plugin</source>
         <translation>Informazioni sul Modulo audio CUE</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="86"/>
+        <location filename="../decodercuefactory.cpp" line="96"/>
         <source>Qmmp CUE Audio Plugin</source>
         <translation>Modulo audio CUE per Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="87"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../decodercuefactory.cpp" line="97"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
@@ -38,21 +38,31 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
+        <source>Common settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="35"/>
+        <source>Automatic file detection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="45"/>
         <source>CUE encoding</source>
         <translation>Codifica CUE</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../settingsdialog.ui" line="51"/>
         <source>Automatic charset detection</source>
         <translation>Rilevazione automaticamente del set di caratteri</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="45"/>
+        <location filename="../settingsdialog.ui" line="61"/>
         <source>Language:</source>
         <translation>Lingua:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="65"/>
+        <location filename="../settingsdialog.ui" line="81"/>
         <source>Default encoding:</source>
         <translation>Codifica predefeinita</translation>
     </message>
