@@ -14,18 +14,18 @@
         <translation>CUE bylos</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="85"/>
+        <location filename="../decodercuefactory.cpp" line="95"/>
         <source>About CUE Audio Plugin</source>
         <translation>Apie CUE audio įskiepį</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="86"/>
+        <location filename="../decodercuefactory.cpp" line="96"/>
         <source>Qmmp CUE Audio Plugin</source>
         <translation>Qmmp CUE audio įskiepis</translation>
     </message>
     <message>
-        <location filename="../decodercuefactory.cpp" line="87"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../decodercuefactory.cpp" line="97"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Sukūrė:Ilya Kotov </translation>
     </message>
 </context>
@@ -38,21 +38,31 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
+        <source>Common settings</source>
+        <translation>Bendri nustatymai</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="35"/>
+        <source>Automatic file detection</source>
+        <translation>Automatinis bylų aptikimas</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="45"/>
         <source>CUE encoding</source>
         <translation>CUE kodavimas</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../settingsdialog.ui" line="51"/>
         <source>Automatic charset detection</source>
         <translation>Automatinis koduotės aptikimas</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="45"/>
+        <location filename="../settingsdialog.ui" line="61"/>
         <source>Language:</source>
         <translation>Kalba:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="65"/>
+        <location filename="../settingsdialog.ui" line="81"/>
         <source>Default encoding:</source>
         <translation>Kodavinas pagal nutylėjimą:</translation>
     </message>
