@@ -62,7 +62,7 @@ const DecoderProperties DecoderSndFileFactory::properties() const
     DecoderProperties properties;
     properties.name = tr("Sndfile Plugin");
     properties.filters << "*.wav" << "*.au" << "*.snd" << "*.aif" << "*.aiff" << "*.8svx";
-    properties.filters << "*.sph" << "*.sf" << "*.voc";
+    properties.filters << "*.sph" << "*.sf" << "*.voc" << "*.w64";
     properties.description = tr("PCM Files");
     //properties.contentType = "";
     properties.shortName = "sndfile";
