@@ -75,13 +75,10 @@ public:
      */
     EffectFactory* factory() const;
     /*!
-     * Assignes factory object.
+     * Creates effect object from \b factory. Returns effect objects if factory is enabled,
+     * otherwise returns \b 0.
      */
-    void setFactory(EffectFactory *factory);
-    /*!
-     * Creates a list of enabled effects.
-     */
-    static QList<Effect*> create();
+    static Effect* create(EffectFactory *factory);
     /*!
      * Returns a list of effect factories.
      */
