@@ -9,52 +9,105 @@
 #include <QStringList>
 #include <QApplication>
 #include <QTimer>
-
-#include "constants.h"
+#include <stdio.h>
+#include "audioparameters.h"
+#include "qmmpsettings.h"
 #include "buffer.h"
-#include "output.h"
 #include "volumecontrol.h"
 #include "qmmp.h"
+#include "output.h"
 
-#include <stdio.h>
+extern "C" {
+#include "equ/iir.h"
+}
 
-Output::Output (QObject* parent) : QThread (parent), m_recycler (stackSize())
+//static functions
+static inline void s8_to_s16(qint8 *in, qint16 *out, qint64 samples)
 {
-    m_handler = 0;
+    for(qint64 i = 0; i < samples; ++i)
+        out[i] = in[i] << 8;
+    return;
+}
+
+static inline void s24_to_s16(qint32 *in, qint16 *out, qint64 samples)
+{
+    for(qint64 i = 0; i < samples; ++i)
+        out[i] = in[i] >> 8;
+    return;
+}
+
+static inline void s32_to_s16(qint32 *in, qint16 *out, qint64 samples)
+{
+    for(qint64 i = 0; i < samples; ++i)
+        out[i] = in[i] >> 16;
+    return;
+}
+
+Output::Output (QObject* parent) : QThread (parent)
+{
+    m_handler = StateHandler::instance();
     m_frequency = 0;
     m_channels = 0;
-    m_kbps = 0;
+    m_format = Qmmp::PCM_UNKNOWM;
     m_totalWritten = 0;
     m_currentMilliseconds = -1;
     m_bytesPerMillisecond = 0;
-    m_userStop = FALSE;
-    m_pause = FALSE;
-    m_finish = FALSE;
+    m_userStop = false;
+    m_finish = false;
+    m_visBuffer = 0;
+    m_visBufferSize = 0;
+    m_kbps = 0;
+    m_skip = false;
+    m_pause = false;
+    m_prev_pause = false;
+    m_useEq = false;
+    m_eqEnabled = false;
+    m_settings = QmmpSettings::instance();
+    connect(m_settings,SIGNAL(eqSettingsChanged()), SLOT(updateEqSettings()));
+    updateEqSettings();
 }
 
-void Output::configure(quint32 freq, int chan, int prec)
+void Output::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
     m_frequency = freq;
     m_channels = chan;
-    m_precision = prec;
-    m_bytesPerMillisecond = freq * chan * (prec / 8) / 1000;
+    m_format = format;
+    QMap<Qmmp::AudioFormat, QString> formatNames;
+    formatNames.insert(Qmmp::PCM_S8, "s8");
+    formatNames.insert(Qmmp::PCM_S16LE, "s16le");
+    formatNames.insert(Qmmp::PCM_S24LE, "s24le");
+    formatNames.insert(Qmmp::PCM_S32LE, "s32le");
+    qDebug("Output: [%s] %d Hz, %d ch, %s", qPrintable(Output::currentFactory()->properties().shortName),
+           freq, chan, qPrintable(formatNames.value(format)));
+    m_bytesPerMillisecond = freq * chan * AudioParameters::sampleSize(format) / 1000;
+    m_recycler.configure(freq, chan, format); //calculate output buffer size
+    //visual buffer
+    if(m_visBuffer)
+        delete [] m_visBuffer;
+    m_visBufferSize = QMMP_BLOCK_FRAMES * 2 * chan; //16-bit samples
+    m_visBuffer = new unsigned char [m_visBufferSize];
+    m_useEq = m_eqEnabled && m_frequency && m_format == Qmmp::PCM_S16LE;
+    if(m_frequency)
+        init_iir(m_frequency);
 }
 
 void Output::pause()
 {
+    mutex()->lock();
     m_pause = !m_pause;
+    mutex()->unlock();
     Qmmp::State state = m_pause ? Qmmp::Paused: Qmmp::Playing;
     dispatch(state);
 }
 
 void Output::stop()
 {
-    m_userStop = TRUE;
+    m_userStop = true;
 }
 
 void Output::finish()
 {
-    m_finish = TRUE;
+    m_finish = true;
 }
 
 qint64 Output::written()
@@ -62,10 +115,11 @@ qint64 Output::written()
     return m_totalWritten;
 }
 
-void Output::seek(qint64 pos)
+void Output::seek(qint64 pos, bool reset)
 {
     m_totalWritten = pos * m_bytesPerMillisecond;
     m_currentMilliseconds = -1;
+    m_skip = isRunning() && reset;
 }
 
 Recycler *Output::recycler()
@@ -83,35 +137,85 @@ void Output::setStateHandler(StateHandler *handler)
     m_handler = handler;
 }
 
+AudioParameters Output::audioParameters() const
+{
+    return AudioParameters(m_frequency, m_channels, m_format);
+}
+
 quint32 Output::sampleRate()
 {
     return m_frequency;
 }
 
-int Output::numChannels()
+int Output::channels()
 {
     return m_channels;
 }
 
-int Output::sampleSize()
+Qmmp::AudioFormat Output::format() const
 {
-    return m_precision;
+    return m_format;
 }
 
+int Output::sampleSize() const
+{
+    return AudioParameters::sampleSize(m_format);
+}
+
+qint64 Output::bufferSize() const
+{
+    return m_recycler.size();
+}
+
+void Output::suspend()
+{}
+
+void Output::resume()
+{}
+
 Output::~Output()
 {}
 
-void Output::dispatchVisual (Buffer *buffer, unsigned long written,
-                             int chan, int prec)
+void Output::dispatchVisual (Buffer *buffer)
 {
     if (!buffer)
         return;
+
+    int sampleSize = AudioParameters::sampleSize(m_format);
+    int samples = buffer->nbytes/sampleSize;
+    int outSize = samples*2;
+    if((m_format != Qmmp::PCM_S16LE) && outSize > m_visBufferSize) //increase buffer size
+    {
+        delete[] m_visBuffer;
+        m_visBufferSize = outSize;
+        m_visBuffer = new unsigned char [m_visBufferSize];
+    }
+    switch(m_format)
+    {
+    case Qmmp::PCM_S8:
+        s8_to_s16((qint8 *)buffer->data, (qint16 *) m_visBuffer, samples);
+        break;
+    case Qmmp::PCM_S16LE:
+        m_visBuffer = buffer->data;
+        outSize = buffer->nbytes;
+        break;
+    case Qmmp::PCM_S24LE:
+        s24_to_s16((qint32 *)buffer->data, (qint16 *) m_visBuffer, samples);
+        break;
+    case Qmmp::PCM_S32LE:
+        s32_to_s16((qint32 *)buffer->data, (qint16 *) m_visBuffer, samples);
+        break;
+    default:
+        return;
+    }
     foreach (Visual *visual, *Visual::visuals())
     {
         visual->mutex()->lock ();
-        visual->add ( buffer, written, chan, prec );
+        visual->add (m_visBuffer, outSize, m_channels);
         visual->mutex()->unlock();
     }
+    if(m_format == Qmmp::PCM_S16LE)
+        m_visBuffer = 0;
 }
 
 
@@ -126,14 +230,13 @@ void Output::clearVisuals()
 }
 
 void Output::dispatch(qint64 elapsed,
-                      qint64 totalTime,
                       int bitrate,
                       int frequency,
                       int precision,
                       int channels)
 {
     if (m_handler)
-        m_handler->dispatch(elapsed, totalTime, bitrate, frequency, precision, channels);
+        m_handler->dispatch(elapsed, bitrate, frequency, precision, channels);
 }
 
 void Output::dispatch(const Qmmp::State &state)
@@ -155,7 +258,7 @@ void Output::run()
     }
     mutex()->unlock ();
 
-    bool done = FALSE;
+    bool done = false;
     Buffer *b = 0;
     qint64 l, m = 0;
 
@@ -164,8 +267,21 @@ void Output::run()
     while (!done)
     {
         mutex()->lock ();
+        if(m_pause != m_prev_pause)
+        {
+            if(m_pause)
+            {
+                suspend();
+                mutex()->unlock();
+                m_prev_pause = m_pause;
+                continue;
+            }
+            else
+                resume();
+            m_prev_pause = m_pause;
+        }
         recycler()->mutex()->lock ();
-        done = m_userStop;
+        done = m_userStop || (m_finish && recycler()->empty());
 
         while (!done && (recycler()->empty() || m_pause))
         {
@@ -173,8 +289,9 @@ void Output::run()
             recycler()->cond()->wakeOne();
             recycler()->cond()->wait(recycler()->mutex());
             mutex()->lock ();
-            done = m_userStop;
+            done = m_userStop || m_finish;
         }
+
         status();
         if (!b)
         {
@@ -182,17 +299,30 @@ void Output::run()
             if (b && b->rate)
                 m_kbps = b->rate;
         }
+
         recycler()->cond()->wakeOne();
         recycler()->mutex()->unlock();
         mutex()->unlock();
         if (b)
         {
-            dispatchVisual(b, m_totalWritten, m_channels, m_precision);
-            changeVolume(b->data, b->nbytes, m_channels);
+            if (m_useEq)
+                iir((void*) b->data, b->nbytes, m_channels);
+            dispatchVisual(b);
+            if (SoftwareVolume::instance())
+                SoftwareVolume::instance()->changeVolume(b, m_channels, m_format);
             l = 0;
             m = 0;
-            while (l < b->nbytes)
+            while (l < b->nbytes && !m_pause)
             {
+                mutex()->lock();
+                if(m_skip)
+                {
+                    m_skip = false;
+                    reset();
+                    mutex()->unlock();
+                    break;
+                }
+                mutex()->unlock();
                 m = writeAudio(b->data + l, b->nbytes - l);
                 if(m >= 0)
                 {
@@ -217,7 +347,7 @@ void Output::run()
     //write remaining data
     if(m_finish)
     {
-        flush();
+        drain();
         qDebug("Output: total written %lld", m_totalWritten);
     }
     dispatch(Qmmp::Stopped);
@@ -234,34 +364,33 @@ void Output::status()
     if (ct > m_currentMilliseconds)
     {
         m_currentMilliseconds = ct;
-        dispatch(m_currentMilliseconds, m_totalWritten, m_kbps,
-                 m_frequency, m_precision, m_channels);
+        dispatch(m_currentMilliseconds, m_kbps,
+                 m_frequency, AudioParameters::sampleSize(m_format)*8, m_channels);
     }
 }
 
-void Output::changeVolume(uchar *data, qint64 size, int chan)
+void Output::updateEqSettings()
 {
-    if (!SoftwareVolume::instance())
-        return;
-    if (chan > 1)
-        for (qint64 i = 0; i < size/2; i+=2)
-        {
-            ((short*)data)[i]*= SoftwareVolume::instance()->left()/100.0;
-            ((short*)data)[i+1]*= SoftwareVolume::instance()->right()/100.0;
-        }
-    else
+    mutex()->lock();
+    m_eqEnabled = m_settings->eqSettings().isEnabled();
+    double preamp = m_settings->eqSettings().preamp();
+    set_preamp(0, 1.0 + 0.0932471 *preamp + 0.00279033 * preamp * preamp);
+    set_preamp(1, 1.0 + 0.0932471 *preamp + 0.00279033 * preamp * preamp);
+    for(int i = 0; i < 10; ++i)
     {
-        int l = qMax(SoftwareVolume::instance()->left(), SoftwareVolume::instance()->right());
-        for (qint64 i = 0; i < size/2; i++)
-            ((short*)data)[i]*= l/100.0;
+        double value =  m_settings->eqSettings().gain(i);
+        set_gain(i,0, 0.03*value+0.000999999*value*value);
+        set_gain(i,1, 0.03*value+0.000999999*value*value);
     }
+    if(isRunning())
+        m_useEq = m_eqEnabled && m_format == Qmmp::PCM_S16LE;
+    mutex()->unlock();
 }
 
 // static methods
 
 QList<OutputFactory*> *Output::m_factories = 0;
 QStringList Output::m_files;
-QTimer *Output::m_timer = 0;
 
 void Output::checkFactories()
 {
@@ -282,10 +411,10 @@ void Output::checkFactories()
                 qWarning("Output: %s", qPrintable(loader.errorString ()));
 
             OutputFactory *factory = 0;
-            if ( plugin )
+            if (plugin)
                 factory = qobject_cast<OutputFactory *> ( plugin );
 
-            if ( factory )
+            if (factory)
             {
                 Output::registerFactory ( factory );
                 m_files << pluginsDir.absoluteFilePath(fileName);
@@ -295,9 +424,9 @@ void Output::checkFactories()
     }
 }
 
-void Output::registerFactory ( OutputFactory *fact )
+void Output::registerFactory (OutputFactory *fact)
 {
-    m_factories->append ( fact );
+    m_factories->append (fact);
 }
 
 Output *Output::create (QObject *parent)
@@ -318,13 +447,13 @@ Output *Output::create (QObject *parent)
     return output;
 }
 
-QList<OutputFactory*> *Output::outputFactories()
+QList<OutputFactory*> *Output::factories()
 {
     checkFactories();
     return m_factories;
 }
 
-QStringList Output::outputFiles()
+QStringList Output::files()
 {
     checkFactories();
     return m_files;
