@@ -23,7 +23,7 @@
 #include <QObject>
 #include <QMap>
 #include <QMutex>
-
+#include "abstractengine.h"
 #include "qmmp.h"
 
 /*! @brief The StateHandler class allows to track information about playback progress.
@@ -68,6 +68,14 @@ public:
      * @param percent Indicates the current percentage of buffering completed.
      */
     virtual void dispatchBuffer(int percent);
+    /*!
+     * Sets next audio engine.
+     */
+    void setNextEngine(AbstractEngine *engine);
+    /*!
+     * Sets current audio engine.
+     */
+    void setCurrentEngine(AbstractEngine *engine);
     /*!
      * Returns the current time (in milliseconds).
      */
@@ -100,6 +108,20 @@ public:
      * Returns the metdata string associated with the given \b key.
      */
     QString metaData(Qmmp::MetaData key);
+    /*!
+     * Sends \b nextTrackRequest() signal manually.
+     */
+    void sendNextTrackRequest();
+    /*!
+     * Returns a pointer to the audio engine which will be used to play next (queued) audio source.
+     * Otherwise returns \b 0
+     */
+    AbstractEngine *nextEngine();
+    /*!
+     * Returns a pointer to the current audio engine.
+     * Otherwise returns \b 0
+     */
+    AbstractEngine *currentEngine();
     /*!
      * Returns a pointer to the first created StateHandler instance.
      */
@@ -146,7 +168,7 @@ signals:
     /*!
      * Emitted before the playback ends.
      */
-    void aboutToFinish();
+    void nextTrackRequest();
      /*!
      * This signal is emitted when the stream reader fills it's buffer.
      * The argument \b progress indicates the current percentage of buffering completed.
@@ -163,6 +185,8 @@ private:
     QMap <Qmmp::MetaData, QString> m_cachedMetaData;
     Qmmp::State m_state;
     QMutex m_mutex;
+    AbstractEngine *m_next_engine;
+    AbstractEngine *m_current_engine;
 };
 
 #endif
