@@ -25,7 +25,6 @@
 #include <QApplication>
 
 #include "visualfactory.h"
-#include "constants.h"
 #include "output.h"
 
 #include "visual.h"
@@ -33,8 +32,8 @@
 
 Visual::Visual(QWidget *parent) : QWidget(parent)
 {
-    setAttribute(Qt::WA_DeleteOnClose, TRUE);
-    setAttribute(Qt::WA_QuitOnClose, FALSE);
+    setAttribute(Qt::WA_DeleteOnClose, true);
+    setAttribute(Qt::WA_QuitOnClose, false);
     m_decoder = 0;
     m_output = 0;
 }
@@ -56,7 +55,7 @@ void Visual::closeEvent (QCloseEvent *event)
     {
         VisualFactory *factory = m_vis_map.key(this);
         m_vis_map.remove(factory);
-        Visual::setEnabled(factory, FALSE);
+        Visual::setEnabled(factory, false);
         emit closedByUser();
     }
     else
@@ -133,7 +132,7 @@ bool Visual::isEnabled(VisualFactory* factory)
 {
     checkFactories();
     if (!m_factories->contains(factory))
-        return FALSE;
+        return false;
     QString name = factory->properties().shortName;
     QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
     QStringList visList = settings.value("Visualization/enabled_plugins").toStringList();
