@@ -59,6 +59,10 @@ public:
      * Returns \b true if "Repeate Track" option is enabled, otherwise returns \b false
      */
     bool isRepeatable() const;
+    /*!
+     * Returns \b true if "No playlist advance" option is enabled, otherwise returns \b false
+     */
+    bool isNoPlaylistAdvance() const;
 
 public slots:
     /*!
@@ -82,6 +86,12 @@ public slots:
      * @param enable Repeate state of the current track (\b true - to repeat, \b false - to stop repeating)
      */
     void setRepeatable(bool enable);
+    /*!
+     * When finished playing a song, don't automatically advance to the next
+     * @param enable State of the 'No playlist advance' option
+     * (\b true - enabled, \b false - normal playback)
+     */
+    void setNoPlaylistAdvance(bool enable);
 
 signals:
     /*!
@@ -89,16 +99,24 @@ signals:
      * @param enabled New repeate state of the current track (\b true - enabled, \b false - disabled)
      */
     void repeatableChanged(bool enabled);
+    /*!
+     * Emitted when state of the "No playlist advance" option changes.
+     * @param enabled New state of this option (\b true - no playlist advance,
+     * \b false - normal playlist behaviour)
+     */
+    void noPlaylistAdvanceChanged(bool enabled);
 
 private slots:
     void playNext();
     void updateNextUrl();
+    void processState(Qmmp::State state);
 
 private:
     PlayListManager *m_pl_manager;
     SoundCore *m_core;
     static MediaPlayer* m_instance;
     bool m_repeat;
+    bool m_noPlaylistAdvance;
     int m_skips;
     QString m_nextUrl;
 };
