@@ -31,21 +31,38 @@ bool ShufflePlayState::next()
 
     if (itm_count > 0)
     {
-        if (m_shuffled_current >= m_shuffled_indexes.count() -1 )
+        if (m_shuffled_current >= m_shuffled_indexes.count() - 1)
         {
             if (!m_model->isRepeatableList())
                 return false;
             else
                 prepare();
         }
-
-        if (m_shuffled_current < m_shuffled_indexes.count() - 1)m_shuffled_current++;
+        else
+            m_shuffled_current = (m_shuffled_current + 1) % m_shuffled_indexes.count();
 
         return m_model->setCurrent(m_shuffled_indexes.at(m_shuffled_current));
     }
     return false;
 }
 
+int ShufflePlayState::nextIndex()
+{
+    int itm_count = m_model->items().count();
+    if(!itm_count)
+        return -1;
+
+
+    if (m_shuffled_current >= m_shuffled_indexes.count() - 1)
+    {
+        if (!m_model->isRepeatableList())
+            return -1;
+        else
+            prepare();
+    }
+    return m_shuffled_indexes.at((m_shuffled_current + 1) % m_shuffled_indexes.count());
+}
+
 bool ShufflePlayState::previous()
 {
     int itm_count = m_model->items().count();
@@ -63,7 +80,8 @@ bool ShufflePlayState::previous()
             }
         }
 
-        if (itm_count > 1) m_shuffled_current --;
+        if (itm_count > 1)
+            m_shuffled_current --;
 
         m_model->setCurrent(m_shuffled_indexes.at(m_shuffled_current));
         return true;
@@ -74,14 +92,14 @@ bool ShufflePlayState::previous()
 void ShufflePlayState::prepare()
 {
     resetState();
-    for (int i = 0;i < m_model->items().count();i++)
+    for(int i = 0;i < m_model->items().count();i++)
     {
         if (i != m_model->currentRow())
             m_shuffled_indexes << i;
     }
 
-    for (int i = 0;i < m_shuffled_indexes.count();i++)
-        m_shuffled_indexes.swap(qrand()%m_shuffled_indexes.size(),qrand()%m_shuffled_indexes.size());
+    for (int i = 0; i < m_shuffled_indexes.count(); i++)
+        m_shuffled_indexes.swap(i, qrand()%m_shuffled_indexes.size());
 
     m_shuffled_indexes.prepend(m_model->currentRow());
 }
@@ -132,3 +150,19 @@ bool NormalPlayState::previous()
     return false;
 }
 
+int NormalPlayState::nextIndex()
+{
+    int itm_count = m_model->items().count();
+    if(!itm_count)
+        return -1;
+
+    if (m_model->currentRow() == itm_count - 1)
+    {
+        if (m_model->isRepeatableList())
+            return 0;
+        else
+            return -1;
+    }
+    return m_model->currentRow() + 1;
+}
+
