@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -435,20 +435,16 @@ void ListWidget::dropEvent(QDropEvent *event)
         event->acceptProposedAction();
         QApplication::restoreOverrideCursor();
 
-        foreach(QUrl u,list_urls)
+        foreach(QUrl u, list_urls)
         {
-            QString add_string = u.toString(QUrl::RemoveScheme);
-            if (!add_string.isEmpty())
-                processFileInfo(QFileInfo(add_string));
+            if(u.scheme() == "file")
+                m_model->add(QFileInfo(u.toLocalFile()).absoluteFilePath());
+            else
+                m_model->add(u.toString());
         }
     }
 }
 
-void ListWidget::processFileInfo(const QFileInfo& info)
-{
-    m_model->add(info.absoluteFilePath());
-}
-
 const QString ListWidget::getExtraString(int i)
 {
     QString extra_string;
