@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -67,7 +67,7 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
                    Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
     setWindowTitle("Qmmp");
 
-    new ActionManager();
+    new ActionManager(this);
 
     //prepare libqmmp and libqmmpui libraries for playing
     m_player = new MediaPlayer(this);
@@ -427,8 +427,7 @@ void MainWindow::createActions()
     m_mainMenu->addAction(SET_ACTION(ActionManager::NEXT, this, SLOT(next())));
     m_mainMenu->addAction(SET_ACTION(ActionManager::PLAY_PAUSE, this, SLOT(playPause())));
     m_mainMenu->addSeparator();
-    m_mainMenu->addAction(QIcon::fromTheme("go-up"), tr("&Jump To File"),
-                          this, SLOT(jumpToFile()), tr("J"));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::JUMP, this, SLOT(jumpToFile())));
     m_mainMenu->addSeparator();
     QMenu *viewMenu = m_mainMenu->addMenu(tr("View"));
     viewMenu->addAction(ACTION(ActionManager::SHOW_PLAYLIST));
