@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,6 +24,7 @@
 #include <QMenu>
 #include <QMouseEvent>
 #include <QSettings>
+#include <QApplication>
 #include <qmmp/qmmp.h>
 #include <qmmp/soundcore.h>
 #include <qmmpui/metadataformatter.h>
@@ -102,7 +103,7 @@ void TextScroller::updateSkin()
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     m_bitmap = settings.value("MainWindow/bitmap_font", false).toBool();
     m_ratio = m_skin->ratio();
-    QString fontname = settings.value("MainWindow/Font").toString();
+    QString fontname = settings.value("MainWindow/Font", QApplication::font().toString()).toString();
     m_font.fromString(fontname);
     if (m_metrics)
         delete m_metrics;
@@ -260,7 +261,7 @@ void TextScroller::preparePixmap(const QString &text, bool scrollable)
          QPainter painter(&m_pixmap);
          painter.setPen(m_color);
          painter.setFont(m_font);
-         if(m_bitmap)
+         if(bitmap)
              drawBitmapText (0,12, fullText, &painter, m_skin);
          else
              painter.drawText (0,12, fullText);
